@@ -141,7 +141,7 @@ class Query(object):
         q = q.fetchall()
         for row in q:
             obj = self.model(*row)
-            obj._new_record = False
+            obj._is_new = False
             yield obj
 
     def _execute(self):
